;Delay and Mute 12 PCB

; When relay is ON the audio is NOT muted.
; Change SYMBOL "Delay_Value" to set startup delay time in milliseconds

;Picaxe 08M2 Pinout
;Pin1 = +V
;Pin2 = C.5 (In, Serial In)
;Pin3 = C.4 (Touch/ADC/Out/In)
;Pin4 = C.3 (In)
;Pin5 = C.2 (In/Out/ADC/pwm/tune/SRQ/hi2c sda)
;Pin6 = C.1 (In/Out/ADC/hserin/SRI/hi2c scl)
;Pin7 = C.0 /Serial Out/Out//hserout/DAC)
;Pin8 = 0V

#Picaxe 08M2
#No_Data
SETFREQ m4

;allow time for system to stabilize
PAUSE 100

'Make all I/O pins inputs initially 
Input C.4 
Input C.2
Input C.1

;Pin assignments

;Control Inputs
SYMBOL Power_Good = pinC.3 '1=good 0=low
SYMBOL Mute_Switch = pinC.2 '0=muted 1=unmuted

;Audio Output (Relay1) Control
SYMBOL Rel_CtrlA = C.4
SYMBOL Rel_CtrlB = C.1

;variables storage
SYMBOL Power_State = b0 '24V Power 1=good 0=off
SYMBOL Muted = b1 'Muted Switch 0=muted 1=unmuted

;INITIALIZE THE BOARD

;******************************************************************************
;******************************************************************************
;Startup Delay in milliseconds to avoid turn-on thumps (e.g. 4000 = 4 seconds)*
PAUSE 4000 '                                                                  *
;******************************************************************************
;******************************************************************************

;Turn relay ON (unmute)
GOSUB Rel_Ctrl_ON 

'main program is a continuous loop to watch for Mute ON and to monitor power status.
Main:

'check if power has been lost
Power_State = Power_Good
IF Power_State = 0 THEN 'power has failed
	GOTO POWERFAIL
ENDIF

'check if "Mute" switch is ON
Muted = Mute_Switch
IF Muted = 0 THEN 'if switch selects "Mute"
	GOSUB Mute_Audio
ENDIF

'Loop back to Main
GOTO Main

'subroutines:

POWERFAIL:
GOSUB Rel_Ctrl_OFF 'immediately mute the output
'Troubleshooting send data to terminal only if needed
SERTXD ("Power Failed!",13,10)
RESET		'Restart the program


'Mute switch ON ("Mute" pad connected to pcb/power ground)
MUTE_AUDIO:
GOSUB Rel_Ctrl_OFF
'Troubleshooting send data to terminal only if needed
SERTXD ("Audio is Muted",13,10)
DO WHILE Muted = 0
	Power_State = Power_Good
	IF Power_State = 0 THEN 'if power is OFF
		GOTO POWERFAIL
	ENDIF
	Muted = Mute_Switch
LOOP
GOSUB Rel_Ctrl_ON:
RETURN

	
'Relay switching subroutines 
'Always make both pins "input" before changing their output state to avoid conflicting states

'Output shorted
Rel_Ctrl_OFF:
SERTXD ("Output SHORTED",13,10)
Input Rel_CtrlA
Input Rel_CtrlB
PAUSE 10
Low Rel_CtrlA
Low Rel_CtrlB
PAUSE 75
RETURN

'Output enabled
Rel_Ctrl_ON:
SERTXD ("Output ENABLED",13,10)'("Power & Mute Status ",#b0," ",#b1,13,10)
Input Rel_CtrlA
Input Rel_CtrlB
PAUSE 10
High Rel_CtrlA
High Rel_CtrlB
PAUSE 75
RETURN	